# IS IT KEYBOARD SMASHING?

## [Repositório Git](https://github.com/fga-eps-mds/2022-2-Squad03)

##  🔎Visão Geral
<li>Qual o objetivo desse software?</li>
Desenvolver um pacote python fazendo uso de técnicas de machine learning para identificar keyboard smashing.
<li>O que é keyboard smashing?</li>
Keyboard smashing é a entrada ilógica e desordenada de dados, que acaba por comprometer a análise textual por sistemas de software.

##  ⚙Funcionalidades
<li>Função que dada uma entrada textual retorne se é um caso de keyboard smashing ou não, inicialmente para a língua inglesa, mas posteriormente temos o interesse de extender para o português.</li>

##  📋Exemplos
<li>yyyyyy</li>
É keyboard smashing.
<li>aslkhfg</li>
É keyboard smashing.
<li>maxxon</li>
Não é keyboard smashing.

##  👨‍💻Contribuidores
[Arthur de Melo](https://github.com/arthurmlv)

[Arthur Grandão](https://github.com/arthurgrandao)

[Douglas Alves](https://github.com/dougAlvs)

[Gabriel Campello](https://github.com/g16c)

[Paulo Victor](https://github.com/PauloVictorFS)

[Rafael Ferreira](https://github.com/RafaelCLG0)

[Sidney Fernando](https://github.com/nando3d3)


##  ©Licence

This software is licensed under the [MIT](https://github.com/nhn/tui.editor/blob/master/LICENSE) ©




## [Git Repository](https://github.com/fga-eps-mds/2022-2-Squad03)

##  🔎Overview
<li>What is the purpose of this software?</li>
Develop a python package using machine learning techniques to identify keyboard smashing.
<li>What is keyboard smashing?</li>
Keyboard smashing is illogical and disorderly data entry, which ends up compromising textual analysis by software systems.

## ⚙Features
<li>Function that, given a textual entry, returns whether it is a case of keyboard smashing or not, initially for the English language, but later we are interested in extending it to Portuguese.</li>

##  📋Examples
<li>yyyyyy</li>
Is keyboard smashing.
<li>aslkhfg</li>
Is keyboard smashing.
<li>maxxon</li>
Is Not keyboard smashing.

##  👨‍💻Contributors
[Arthur de Melo](https://github.com/arthurmlv)

[Arthur Grandão](https://github.com/arthurgrandao)

[Douglas Alves](https://github.com/dougAlvs)

[Gabriel Campello](https://github.com/g16c)

[Paulo Victor](https://github.com/PauloVictorFS)

[Rafael Ferreira](https://github.com/RafaelCLG0)

[Sidney Fernando](https://github.com/nando3d3)





